@@ -1,3 +1,4 @@
+from django.db.models import Prefetch
 from rest_framework.viewsets import ReadOnlyModelViewSet
 
 from .models import GlossaryEntry
@@ -9,6 +10,8 @@ class GlossaryEntryEndpoint(ReadOnlyModelViewSet):
     Endpoint that provides the database table of all glossary entries.
     """
 
-    queryset = GlossaryEntry.objects.all()
+    queryset = GlossaryEntry.objects.order_by("term").prefetch_related(
+        Prefetch("links", queryset=GlossaryEntry.objects.order_by("term"))
+    )
     serializer_class = GlossaryEntrySerializer
     name = "glossaryentry"
