@@ -10,9 +10,7 @@ class QuizAnswerInline(admin.TabularInline):
 
 class QuizQuestionAdmin(admin.ModelAdmin):
     list_display = ["id", "text"]
-    inlines = [
-        QuizAnswerInline,
-    ]
+    inlines = [QuizAnswerInline]
 
 
 admin.site.register(QuizQuestion, QuizQuestionAdmin)
