@@ -1,46 +1,31 @@
 from rest_framework import serializers
 
 from solid_backend.photograph.serializers import PhotographSerializer
+from solid_backend.utils.serializers import DynamicExcludeModelSerializer
 
 from .models import Slideshow, SlideshowImage, SlideshowPage
 
 
-class SlideshowImageLessSerializer(serializers.ModelSerializer):
+class SlideshowImageSerializer(DynamicExcludeModelSerializer):
     img = PhotographSerializer()
 
     class Meta:
         model = SlideshowImage
-        fields = ["id", "position", "title", "img", "caption"]
+        fields = "__all__"
 
 
-class SlideshowPageLessSerializer(serializers.ModelSerializer):
-    images = SlideshowImageLessSerializer(many=True)
+class SlideshowPageSerializer(DynamicExcludeModelSerializer):
+    images = SlideshowImageSerializer(exclude="page", many=True)
 
     class Meta:
         model = SlideshowPage
-        fields = ["id", "position", "title", "text", "images"]
+        fields = "__all__"
 
 
 class SlideshowSerializer(serializers.ModelSerializer):
     img = PhotographSerializer()
-    pages = SlideshowPageLessSerializer(many=True)
+    pages = SlideshowPageSerializer(exclude="show", many=True)
 
     class Meta:
         model = Slideshow
-        fields = "__all__"
-
-
-class SlideshowPageSerializer(serializers.ModelSerializer):
-    images = SlideshowImageLessSerializer(many=True)
-
-    class Meta:
-        model = SlideshowPage
-        fields = "__all__"
-
-
-class SlideshowImageSerializer(serializers.ModelSerializer):
-    img = PhotographSerializer()
-
-    class Meta:
-        model = SlideshowImage
-        fields = "__all__"
+        exclude = ["active"]
